@@ -5,14 +5,13 @@ Core API functions and initialization routines.
 import os
 import sys
 import logging
-import operator
 
 from .py27compat import configparser, filter
+from .py33compat import max
 
 from . import backend
 from .util import platform_ as platform
 from .backends import fail
-from .backends.chainer import ChainerBackend
 
 
 log = logging.getLogger(__name__)
@@ -80,33 +79,23 @@ def recommended(backend):
     return backend.priority >= 1
 
 
-by_priority = operator.attrgetter('priority')
-
-
-def _create_chained_backend(keyrings):
-    """
-    If one keyring is available, returns it. If more than one, returns a
-    single keyring that chains them. If no keyrings, returns None.
-    """
-    keyrings = sorted((k for k in keyrings if k.priority >= 1),
-                      key=by_priority, reverse=True)
-    if keyrings:
-        if len(keyrings) == 1:
-            return keyrings[0]
-        return ChainerBackend(keyrings)
-
-
 def init_backend(limit=None):
     """
     Load a keyring specified in the config file or infer the best available.
+
+    Limit, if supplied, should be a callable taking a backend and returning
+    True if that backend should be included for consideration.
     """
+    # save the limit for the chainer to honor
+    backend._limit = limit
+
+    # get all keyrings passing the limit filter
     keyrings = filter(limit, backend.get_all_keyring())
 
     set_keyring(
         load_env()
         or load_config()
-        or _create_chained_backend(keyrings)
-        or fail.Keyring()
+        or max(keyrings, default=fail.Keyring(), key=backend.by_priority)
     )
 
 
